aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap
diff options
context:
space:
mode:
Diffstat (limited to 'wiretap')
-rw-r--r--wiretap/eyesdn.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/wiretap/eyesdn.c b/wiretap/eyesdn.c
index 6c47523d2c..7835625941 100644
--- a/wiretap/eyesdn.c
+++ b/wiretap/eyesdn.c
@@ -43,7 +43,7 @@
* Each Frame starts with the 0xff Flag byte
* - Bytes 0-2: timestamp (long usec in network byte order)
* - Bytes 3-7: timestamp (40bits sec since 1970 in network byte order)
* - Byte 8: channel (0 for D channel, 1-30 for B1-B30)
* - Byte 9: Sender (0 NT, 1 TE)
* - Byte 10-11: frame size in bytes
* - Byte 12-n: Frame Payload
@@ -260,7 +260,7 @@ parse_eyesdn_rec_hdr(wtap *wth, FILE_T fh,
pkt_len = (pkt_len << 8) | ((unsigned long) hdr[11]);
/* sanity checks */
- if(channel>30) {
+ if((channel>30)&&(channel!=129)) {
*err = WTAP_ERR_BAD_RECORD;
*err_info = g_strdup_printf("eyesdn: bad channel number %u",
channel);
@@ -43,7 +43,7 @@
* - Bytes 0-2: timestamp (long usec in network byte order)
* - Bytes 3-7: timestamp (40bits sec since 1970 in network byte order)
- * - Byte 8: channel (0 for D channel, 1-30 for B1-B30)
+ * - Byte 8: channel (0 for D channel, 1-30 for B1-B30, 129 for ATM)
* - Byte 9: Sender (0 NT, 1 TE)
* - Byte 10-11: frame size in bytes